summaryrefslogtreecommitdiffstats
path: root/video/csputils.c
diff options
context:
space:
mode:
authorwm4 <wm4@nowhere>2015-12-09 00:22:12 +0100
committerwm4 <wm4@nowhere>2015-12-09 00:23:36 +0100
commit45ae0716be3319bac4585b8fedac529a0809a44c (patch)
tree3d0c79a7d5e5bb8778118e9551295cedf9ed3667 /video/csputils.c
parentc5c7b239b6386940a8063c6954db2a4705ce3251 (diff)
downloadmpv-45ae0716be3319bac4585b8fedac529a0809a44c.tar.bz2
mpv-45ae0716be3319bac4585b8fedac529a0809a44c.tar.xz
csputils: rename "yuv2rgb" functions
They're not necessarily restricted to YUV aka YCbCr. vo_direct3d.c and demux_disc.c (DVD specific code) changes untested.
Diffstat (limited to 'video/csputils.c')
-rw-r--r--video/csputils.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/video/csputils.c b/video/csputils.c
index ff5ae3870d..fb9d971517 100644
--- a/video/csputils.c
+++ b/video/csputils.c
@@ -3,7 +3,7 @@
*
* Copyleft (C) 2009 Reimar Döffinger <Reimar.Doeffinger@gmx.de>
*
* mp_invert_yuv2rgb based on DarkPlaces engine, original code (GPL2 or later)
*
* This file is part of mpv.
*
@@ -573,7 +573,7 @@ double mp_get_csp_mul(enum mp_csp csp, int input_bits, int texture_bits)
return (1LL << input_bits) / ((1LL << texture_bits) - 1.) * 255 / 256;
}
-/* Fill in the Y, U, V vectors of a yuv2rgb conversion matrix
+/* Fill in the Y, U, V vectors of a yuv-to-rgb conversion matrix
* based on the given luma weights of the R, G and B components (lr, lg, lb).
* lr+lg+lb is assumed to equal 1.
* This function is meant for colorspaces satisfying the following
@@ -605,7 +605,7 @@ static void luma_coeffs(struct mp_cmat *mat, float lr, float lg, float lb)
}
// get the coefficients of the yuv -> rgb conversion matrix
-void mp_get_yuv2rgb_coeffs(struct mp_csp_params *params, struct mp_cmat *m)
+void mp_get_csp_matrix(struct mp_csp_params *params, struct mp_cmat *m)
{
int colorspace = params->colorspace;
if (colorspace <= MP_CSP_AUTO || colorspace >= MP_CSP_COUNT)
@@ -767,7 +767,7 @@ int mp_csp_equalizer_set(struct mp_csp_equalizer *eq, const char *property,
return 1;
}
-void mp_invert_yuv2rgb(struct mp_cmat *out, struct mp_cmat *in)
+void mp_invert_cmat(struct mp_cmat *out, struct mp_cmat *in)
{
*out = *in;
mp_invert_matrix3x3(out->m);
@@ -3,7 +3,7 @@
* Copyleft (C) 2009 Reimar Döffinger <Reimar.Doeffinger@gmx.de>
*
- * mp_invert_yuv2rgb based on DarkPlaces engine, original code (GPL2 or later)
+ * mp_invert_cmat based on DarkPlaces engine, original code (GPL2 or later)
*
* This file is part of mpv.